@@ -5,10 +5,12 @@ use std::collections::HashSet;
 
 use anyhow::Result;
 use deno_ast::ModuleSpecifier;
-use deno_graph::Module;
+use deno_graph::EsModule;
 
 use crate::graph::ModuleGraph;
+use crate::graph::ModuleRef;
 
+#[derive(Debug)]
 pub struct DeclarationFileResolution {
   pub selected: TypesDependency,
   /// Specified declaration dependencies that were ignored.
@@ -25,11 +27,11 @@ pub struct TypesDependency {
 
 pub fn resolve_declaration_file_mappings(
   module_graph: &ModuleGraph,
-  modules: &[&Module],
+  modules: &[ModuleRef<'_>],
 ) -> Result<BTreeMap<ModuleSpecifier, DeclarationFileResolution>> {
   let mut type_dependencies = BTreeMap::new();
 
-  for module in modules {
+  for module in modules.iter().filter_map(|m| m.as_es_module()) {
     fill_types_for_module(module, &mut type_dependencies)?;
   }
 
@@ -89,9 +91,9 @@ fn select_best_types_dep(
         true
       } else {
         // as a last resort, use the declaration file that's the largest
-        let dep_file_len = module_graph.get(&dep.specifier).source.len();
+        let dep_file_len = module_graph.get(&dep.specifier).source().len();
         let selected_dep_file_len =
-          module_graph.get(&selected_dep.specifier).source.len();
+          module_graph.get(&selected_dep.specifier).source().len();
         dep_file_len > selected_dep_file_len
       }
     } else {
@@ -105,7 +107,7 @@ fn select_best_types_dep(
 }
 
 fn fill_types_for_module(
-  module: &Module,
+  module: &EsModule,
   type_dependencies: &mut BTreeMap<ModuleSpecifier, HashSet<TypesDependency>>,
 ) -> Result<()> {
   // check for the module specifying its type dependency
@@ -139,7 +141,7 @@ fn fill_types_for_module(
   return Ok(());
 
   fn add_type_dependency(
-    module: &Module,
+    module: &EsModule,
     code_specifier: &ModuleSpecifier,
     type_specifier: &ModuleSpecifier,
     type_dependencies: &mut BTreeMap<ModuleSpecifier, HashSet<TypesDependency>>,
