@@ -8,16 +8,11 @@ use std::path::PathBuf;
 use anyhow::Result;
 use deno_ast::MediaType;
 use deno_ast::ModuleSpecifier;
-use regex::Regex;
 
 use crate::graph::ModuleGraph;
 use crate::specifiers::Specifiers;
 use crate::utils::url_to_file_path;
 
-lazy_static! {
-  static ref HAS_EXTENSION_RE: Regex = Regex::new(r"\.[A-Za-z0-9]*$").unwrap();
-}
-
 pub struct Mappings {
   inner: HashMap<ModuleSpecifier, PathBuf>,
 }
@@ -53,7 +48,7 @@ impl Mappings {
       Vec<(ModuleSpecifier, MediaType)>,
     )> = Vec::new();
     for remote_specifier in specifiers.remote.iter() {
-      let media_type = module_graph.get(remote_specifier).media_type;
+      let media_type = module_graph.get(remote_specifier).media_type();
       let mut found = false;
       for (root_specifier, specifiers) in root_remote_specifiers.iter_mut() {
         if let Some(relative_url) =
@@ -112,9 +107,8 @@ impl Mappings {
       let file_path = mappings.get(code_specifier).unwrap();
       let new_file_path = file_path.with_extension("d.ts");
       if let Some(past_path) = mappings.insert(to.clone(), new_file_path) {
-        // this would indicate a programming error
         panic!(
-          "Already had path {} in map when adding declaration file for {}. Adding: {}",
+          "Programming error: Already had path {} in map when adding declaration file for {}. Adding: {}",
           past_path.display(),
           code_specifier,
           to
@@ -122,6 +116,20 @@ impl Mappings {
       }
     }
 
+    // add the redirects in the graph to the mappings
+    for (key, value) in module_graph.redirects() {
+      if !mappings.contains_key(key) {
+        if let Some(path) = mappings.get(value).map(ToOwned::to_owned) {
+          mappings.insert(key.clone(), path);
+        } else {
+          panic!(
+            "Programming error: Could not find the mapping for {}",
+            value
+          );
+        }
+      }
+    }
+
     Ok(Mappings { inner: mappings })
   }
 
