@@ -1,7 +1,9 @@
 // Copyright 2018-2021 the Deno authors. All rights reserved. MIT license.
 
+mod get_ignore_line_indexes;
 mod get_top_level_decls;
 mod helpers;
 
+pub use get_ignore_line_indexes::*;
 pub use get_top_level_decls::*;
 pub use helpers::*;
