@@ -3,11 +3,11 @@
 mod analyze;
 mod deno_comment_directives;
 mod deno_globals;
-mod module_specifiers;
+mod imports_exports;
 mod polyfill;
 
 pub use analyze::get_ignore_line_indexes;
 pub use deno_comment_directives::*;
 pub use deno_globals::*;
-pub use module_specifiers::*;
+pub use imports_exports::*;
 pub use polyfill::*;
