@@ -89,20 +89,27 @@ async fn transform_deno_shim() {
 
 #[tokio::test]
 async fn no_transform_deno_ignored() {
-  assert_identity_transforms(vec!["// deno-shim-ignore\nDeno.readTextFile();"])
+  assert_identity_transforms(vec!["// dnt-shim-ignore\nDeno.readTextFile();"])
     .await;
 }
 
 #[tokio::test]
-async fn transform_deno_shim_with_name_collision() {
-  assert_transforms(vec![(
-    "Deno.readTextFile(); const denoShim = {};",
-    concat!(
-      r#"import * as denoShim1 from "test-shim";"#,
-      "\ndenoShim1.Deno.readTextFile(); const denoShim = {};"
-    ),
-  )])
-  .await;
+async fn transform_legacy_deno_shim_ignore_warnings() {
+  // this was renamed to dnt-shim-ignore
+  let result = TestBuilder::new()
+    .with_loader(|loader| {
+      loader
+        .add_local_file("/mod.ts", "// deno-shim-ignore\nDeno.readTextFile();");
+    })
+    .transform()
+    .await
+    .unwrap();
+
+  assert_eq!(result.warnings, vec!["deno-shim-ignore has been renamed to dnt-shim-ignore. Please rename it in file:///mod.ts"]);
+  assert_files!(
+    result.main.files,
+    &[("mod.ts", "// deno-shim-ignore\nDeno.readTextFile();")]
+  );
 }
 
 #[tokio::test]
@@ -372,7 +379,10 @@ async fn transform_local_file_not_exists() {
     .err()
     .unwrap();
 
-  assert_eq!(err_message.to_string(), "file not found (file:///other.ts)");
+  assert_eq!(
+    err_message.to_string(),
+    r#"Module not found "file:///other.ts"."#
+  );
 }
 
 #[tokio::test]
@@ -392,7 +402,7 @@ async fn transform_remote_file_not_exists() {
 
   assert_eq!(
     err_message.to_string(),
-    "Not found. (http://localhost/other.ts)"
+    r#"Module not found "http://localhost/other.ts"."#
   );
 }
 
@@ -438,7 +448,7 @@ async fn transform_parse_error() {
     .err()
     .unwrap();
 
-  assert_eq!(err_message.to_string(), "The module's source code could not be parsed: Expected ';', '}' or <eof> at http://localhost/declarations.d.ts:1:6 (http://localhost/declarations.d.ts)");
+  assert_eq!(err_message.to_string(), "The module's source code could not be parsed: Expected ';', '}' or <eof> at http://localhost/declarations.d.ts:1:6");
 }
 
 #[tokio::test]
@@ -1137,3 +1147,176 @@ async fn polyfills_test_files() {
   assert_eq!(result.test.entry_points, &[PathBuf::from("mod.test.ts")]);
   assert_eq!(result.test.shim_used, false);
 }
+
+#[tokio::test]
+async fn redirects_general() {
+  let result = TestBuilder::new()
+    .with_loader(|loader| {
+      loader
+        .add_local_file("/mod.ts", "import './other.deno.ts';")
+        .add_local_file("/other.deno.ts", "console.log(5);")
+        .add_local_file(
+          "/other.node.ts",
+          concat!(
+            "import * as fs from 'fs';\n",
+            "import { myFunction } from './myFunction.ts'\n",
+            "export function test() {\n",
+            "  // dnt-shim-ignore\n",
+            "  Deno.readFileSync('test');\n",
+            "  Object.hasOwn({}, 'prop');\n",
+            "}",
+          ),
+        )
+        .add_local_file("/myFunction.ts", "export function myFunction() {}");
+    })
+    .add_redirect("file:///other.deno.ts", "file:///other.node.ts")
+    .transform()
+    .await
+    .unwrap();
+
+  assert_files!(
+    result.main.files,
+    &[
+      (
+        "mod.ts",
+        concat!(
+          "import './_dnt.polyfills.js';\n",
+          "import './other.node.js';"
+        ),
+      ),
+      (
+        "other.node.ts",
+        concat!(
+          "import * as fs from 'fs';\n",
+          "import { myFunction } from './myFunction.js'\n",
+          "export function test() {\n",
+          "  // dnt-shim-ignore\n",
+          "  Deno.readFileSync('test');\n",
+          "  Object.hasOwn({}, 'prop');\n",
+          "}",
+        )
+      ),
+      ("myFunction.ts", "export function myFunction() {}",),
+      (
+        "_dnt.polyfills.ts",
+        include_str!("../src/polyfills/scripts/object-has-own.ts")
+      ),
+    ]
+  );
+  assert_eq!(result.main.entry_points, &[PathBuf::from("mod.ts")]);
+  assert_eq!(result.main.shim_used, false);
+}
+
+#[tokio::test]
+async fn redirect_entrypoint() {
+  let result = TestBuilder::new()
+    .with_loader(|loader| {
+      loader
+        .add_local_file("/mod.deno.ts", "console.log(5);")
+        .add_local_file("/mod.node.ts", "5;");
+    })
+    .entry_point("file:///mod.deno.ts")
+    .add_redirect("file:///mod.deno.ts", "file:///mod.node.ts")
+    .transform()
+    .await
+    .unwrap();
+
+  assert_files!(result.main.files, &[("mod.node.ts", "5;")]);
+  assert_eq!(result.main.entry_points, &[PathBuf::from("mod.node.ts")]);
+  assert_eq!(result.main.shim_used, false);
+}
+
+#[tokio::test]
+async fn redirect_not_found() {
+  let err_message = TestBuilder::new()
+    .with_loader(|loader| {
+      loader.add_local_file("/mod.ts", "console.log(5);");
+    })
+    .add_redirect("file:///mod.deno.ts", "file:///mod.node.ts")
+    .transform()
+    .await
+    .err()
+    .unwrap();
+
+  assert_eq!(
+    err_message.to_string(),
+    concat!(
+      "The following specifiers were indicated to be redirected, but were not found:\n",
+      "  * file:///mod.deno.ts",
+    ),
+  );
+}
+
+#[tokio::test]
+async fn json_module_import_default() {
+  let result = TestBuilder::new()
+    .with_loader(|loader| {
+      loader
+        .add_local_file(
+          "/mod.ts",
+          r#"import jsonData from './data.json' assert { type: 'json' };"#,
+        )
+        .add_local_file("/data.json", r#"{ "prop": 5 }"#);
+    })
+    .transform()
+    .await
+    .unwrap();
+
+  assert_files!(
+    result.main.files,
+    &[("mod.ts", r#"const jsonData = JSON.parse(`{ "prop": 5 }`);"#),]
+  );
+}
+
+#[tokio::test]
+async fn json_module_dynamic_import() {
+  let result = TestBuilder::new()
+    .with_loader(|loader| {
+      loader
+        .add_local_file(
+          "/mod.ts",
+          r#"const jsonData = await import('./data.json', { assert: { type: 'json' } });"#
+        )
+        .add_local_file("/data.json", r#"{ "prop": 5 }"#);
+    })
+    .transform()
+    .await
+    .unwrap();
+
+  assert_files!(
+    result.main.files,
+    &[(
+      "mod.ts",
+      r#"const jsonData = await Promise.resolve({ default: JSON.parse(`{ "prop": 5 }`) });"#
+    ),]
+  );
+}
+
+#[tokio::test]
+async fn json_module_re_export_not_supported() {
+  let err = TestBuilder::new()
+    .with_loader(|loader| {
+      loader
+        .add_local_file(
+          "/mod.ts",
+          r#"export { default as Test } from './data.json' assert { type: "json" };"#
+        )
+        .add_local_file("/data.json", r#"{ "prop": 5 }"#);
+    })
+    .transform()
+    .await
+    .err()
+    .unwrap();
+
+  assert_eq!(
+    format!("{:?}", err),
+    concat!(
+      "Issue getting text changes from file:///mod.ts\n",
+      "\n",
+      "Caused by:\n",
+      "    Re-exporting JSON modules has not been implemented. If you need this functionality, please open an issue in dnt's repo.\n",
+      "    \n",
+      "    As a workaround, consider importing the module with an import declaration then exporting the identifier on a separate statement."
+    )
+  );
+}
